@@ -7,20 +7,15 @@ use Carp;
 use Data::Dump ();
 use Net::LDAP;
 use Net::LDAP::Entry;
-use Net::LDAP::Control::Paged;
-use Net::LDAP::Constant qw(LDAP_CONTROL_PAGED);
 use Net::LDAP::Batch;
 use Net::LDAP::Class::Metadata;
 
 use Net::LDAP::Class::MethodMaker (
-    'scalar --get_set_init' => [qw( ldap ldap_entry debug error )],
-    'scalar'                => [qw( batch prev_batch )],
-    'object_or_class_meta'  => [qw( attributes unique_attributes base_dn )],
-);
+    'scalar --get_set_init' => [qw( ldap ldap_entry debug batch )], );
 
-use overload '""' => 'stringify', 'fallback' => 1;
+use overload '""' => 'stringify';
 
-our $VERSION = '0.18_03';
+our $VERSION = '0.01';
 
 =head1 NAME
 
@@ -33,7 +28,7 @@ Net::LDAP::Class - object-relational mapper for Net::LDAP
  package MyLDAPClass;
  use base qw( Net::LDAP::Class );
  
- __PACKAGE__->metadata->setup(
+ __PACKAGE__->meta->setup(
     attributes          => [qw( name address phone email )],
     unique_attributes   => [qw( email )],
     base_dn             => 'dc=mycompany,dc=com',
@@ -78,7 +73,7 @@ uses to great effect for RDBMS management.
 
 =head1 METHODS
 
-NLC uses the Rose::Object package to create methods and handle the mundane get/set features.
+NLC uses the Rose::Object package to create methods and handle the mundate get/set features.
 In addition, Net::LDAP::Class::MethodMaker implements a new method type called B<related_objects>
 which handles the get/set/fetch of NLC objects related to a given NLC object. Typically these
 are Users and Groups. A User is typically related to one or more Groups, and a Group is typically
@@ -97,7 +92,7 @@ sub init {
     my $self = shift;
     $self->SUPER::init(@_);
 
-    my $meta = $self->metadata;
+    my $meta = $self->meta;
     if ( !$meta or !$meta->is_initialized ) {
         croak
             "must initialize Metadata class before instantiating a new object";
@@ -112,35 +107,58 @@ sub init {
     return $self;
 }
 
-=head2 metadata_class
+=head2 meta_class
 
 Returns 'Net::LDAP::Class::Metadata' by default.
 
 =cut
 
-sub metadata_class {'Net::LDAP::Class::Metadata'}
+sub meta_class {'Net::LDAP::Class::Metadata'}
 
-=head2 metadata
+=head2 meta
 
-Returns an instance of the metadata_class() containing all the metadata for
+Returns an instance of the meta_class() containing all the metadata for
 the NLC class. May be called as a class or object method.
 
 =cut
 
-sub metadata {
+sub meta {
     my ($self) = shift;
 
     # object method
     if ( ref $self ) {
-        return $self->{_meta}
-            ||= $self->metadata_class->for_class( ref $self );
+        return $self->{_meta} ||= $self->meta_class->for_class( ref $self );
     }
 
     # class method
     return $Net::LDAP::Class::Metadata::Objects{$self}
-        || $self->metadata_class->for_class($self);
+        || $self->meta_class->for_class($self);
 }
 
+=head2 attributes
+
+Shortcut for $self->meta->attributes.
+
+=cut
+
+sub attributes { shift->meta->attributes }
+
+=head2 unique_attributes
+
+Shortcut for $self->meta->unique_attributes.
+
+=cut
+
+sub unique_attributes { shift->meta->unique_attributes }
+
+=head2 base_dn
+
+Shortcut for $self->meta->base_dn.
+
+=cut
+
+sub base_dn { shift->meta->base_dn }
+
 =head2 init_ldap
 
 If you do not pass a Net::LDAP object to new(), you may instead 
@@ -213,7 +231,7 @@ By default all NLC-derived objects are overloaded with this method.
 
 sub stringify {
     my $self = shift;
-    for my $key ( @{ $self->unique_attributes } ) {
+    for my $key ( @{ $self->unique_keys } ) {
         my $val = $self->$key;
         return $val if defined $val;
     }
@@ -262,17 +280,13 @@ sub find {
         croak "must indicate base_dn in opts or call as object method";
     }
 
-    my $attr = delete $opts{attrs} || $self->attributes;
-
     my $msg = $ldap->search(
-        base  => $base,
-        attrs => $attr,
+        base => $base,
         %opts,
-    );
 
-    if ( $msg->code ) {
-        croak $self->get_ldap_error($msg);
-    }
+        # Net::LDAP::FAQ claims this should return everything for LDAPv2
+        attrs => [],
+    );
 
     my @results;
 
@@ -302,7 +316,7 @@ sub create {
         croak
             "at least one unique attribute must be set in order to create()";
     }
-    my @action = $self->action_for_create(@_) or return;
+    my @action = $self->action_for_create or return;
     $self->do_batch(@action);
     $self->read or croak "cannot read newly created $self";
     return $self;
@@ -357,13 +371,14 @@ sub read {
 
     my $base_dn = delete $opts{base_dn} || $self->base_dn;
 
-    $self->debug && warn "read() within $base_dn : $filter=$value\n";
-
     my $msg = $self->ldap->search(
         base   => $base_dn,
         scope  => "sub",
         filter => "($filter=$value)",
-        attrs  => $self->attributes,
+
+        # Net::LDAP::FAQ claims this should return everything for LDAPv2
+        # but perhaps we should explicitly call $self->attributes instead??
+        attrs => [],
     );
 
     if ( $msg->count() > 0 ) {
@@ -414,7 +429,7 @@ sub update {
     unless ( $self->ldap_entry ) {
         croak "can't update() without first having a Net::LDAP::Entry loaded";
     }
-    my @action = $self->action_for_update(@_) or return;
+    my @action = $self->action_for_update or return;
 
     # clear, since action_for_update() has already used them.
     $self->{_was_set} = {};
@@ -451,42 +466,17 @@ Returns the object in any case.
 
 sub read_or_create {
     my $self = shift;
-    if ( !$self->read(@_) ) {
-        $self->create(@_);
+    if ( !$self->read ) {
+        $self->create;
     }
     return $self;
 }
 
-=head2 validate( I<attr_name>, I<attr_value> )
-
-Called by MethodMaker every time an attribute is set with 
-a MethodMaker-created method.
-
-If validate() returns true, I<attr_value> is set. If validate()
-returns false, a fatal error is thrown and error() set.
-
-This method should be overriden in your subclass to provide
-schema-specific validation. The default behaviour is a no-op
-(always returns true).
-
-=cut
-
-sub validate {
-    my ( $self, $attr, $value ) = @_;
-    if ( $self->debug ) {
-        warn "validate $attr: $value\n";
-    }
-    return 1;
-}
-
 =head2 do_batch( I<array_of_actions> )
 
-Creates (if batch() is not already set) 
-and runs a Net::LDAP::Batch object, passing it
+Creates and runs a Net::LDAP::Batch object, passing it
 the I<array_of_actions> to run. Will croak on any error.
 
-Returns the Net::LDAP::Batch object on success.
-
 =cut
 
 sub do_batch {
@@ -496,33 +486,12 @@ sub do_batch {
         warn "no actions to execute\n";
         return;
     }
-    my $batch = $self->batch || Net::LDAP::Batch->new(
-        ldap  => $self->ldap,
-        debug => $self->debug,
+    my $batch = Net::LDAP::Batch->new(
+        ldap    => $self->ldap,
+        actions => \@actions,
+        debug   => $self->debug,
     );
-    if ( $self->debug ) {
-        warn "Batch: " . Data::Dump::dump($batch);
-    }
-    $batch->add_actions(@actions);
-    $self->prev_batch($batch);
     $batch->do or croak $batch->error;
-    return $batch;
-}
-
-=head2 add_to_batch( I<array_of_actions> )
-
-Initializes (if necessary) and adds I<array_of_actions>
-to the Net::LDAP::Batch object in batch().
-
-=cut
-
-sub add_to_batch {
-    my $self = shift;
-    my $batch = $self->batch || Net::LDAP::Batch->new(
-        ldap  => $self->ldap,
-        debug => $self->debug
-    );
-    $batch->add_actions(@_);
     $self->batch($batch);
 }
 
@@ -535,11 +504,11 @@ by batch(). If there is not batch() set, will croak.
 
 sub rollback {
     my $self = shift;
-    if ( $self->prev_batch ) {
-        $self->prev_batch->rollback or croak $self->prev_batch->error;
+    if ( $self->batch ) {
+        $self->batch->rollback or croak $self->batch->error;
     }
     else {
-        croak "no prev_batch to rollback";
+        croak "no batch to rollback";
     }
     return 1;
 }
@@ -587,7 +556,7 @@ sub check_unique_attributes_set {
     my $self = shift;
     my $uk   = $self->unique_attributes;
     if ( !ref($uk) eq 'ARRAY' ) {
-        croak "unique_attributes must be an ARRAY ref";
+        croak "unique_keys must be an ARRAY ref";
     }
     for my $key (@$uk) {
         if ( defined $self->$key ) {
@@ -642,128 +611,6 @@ sub dump {
     return Data::Dump::dump($self);
 }
 
-=head2 has_local_changes
-
-Convenience method. Returns true if the object has had any values
-set since the last time it was written to the server.
-
-=cut
-
-sub has_local_changes {
-    my $self = shift;
-    return scalar keys %{ $self->{_was_set} };
-}
-
-=head2 batch
-
-Get/set the Net::LDAP::Batch object for the current transaction. Typically you
-don't want to mess with this but documented for completeness.
-
-=head2 prev_batch
-
-Get/set the Net::LDAP::Batch object for the just-completed transaction.
-Typically you don't want to mess with this but documented for completeness.
-
-=cut
-
-=head2 act_on_all( I<code_ref> [, I<opts>] )
-
-Performs I<coderef> sub reference on all records in LDAP. 
-The I<coderef> should expect one argument: a Net::LDAP::Class-derived
-object.
-
-act_on_all() operates using Net::LDAP::Control::Paged, performing
-a search() using a filter based on unique_attributes() and iterating
-over all matches in groups of (by default) 500. You may set the 
-pager size in I<opts>. I<opts> should be a hash ref. The following
-key/value pairs are supported:
-
-=over
-
-=item page_size
-
-Default: 500. Sets the Net::LDAP::Control::Paged size.
-
-=item filter
-
-Default: unique_atttributes->[0] = '*'
-
-Set the filter for the search.
-
-=back
-
-Returns the number of Net::LDAP::Class results acted upon.
-
-=cut
-
-sub act_on_all {
-    my $self    = shift;
-    my $coderef = shift or croak "coderef required";
-    my $opts    = shift || {};
-    my $class   = ref($self) || $self;
-
-    if ( ref $coderef ne 'CODE' ) {
-        croak "coderef is not a CODE reference";
-    }
-
-    my $filter = $opts->{filter}
-        || $self->metadata->unique_attributes->[0] . '=*';
-    my $page_size = $opts->{page_size} || 500;
-
-    my $ldap = $self->ldap;
-    my $page = Net::LDAP::Control::Paged->new( size => $page_size );
-    my $cookie;
-    my @args = (
-        'base'    => $self->metadata->base_dn,
-        'filter'  => "($filter)",
-        'attrs'   => $self->metadata->attributes,
-        'control' => [$page],
-    );
-
-    my $count = 0;
-
-PAGE: while ( my $ldap_search = $ldap->search(@args) ) {
-
-        # fatal on search error
-        croak "error searching ldap: ", $self->get_ldap_error($ldap_search)
-            if ( $ldap_search->code );
-
-    ENTRY: while ( my $ldap_entry = $ldap_search->shift_entry ) {
-
-            $count++;
-
-            my $nlc = $class->new(
-                ldap       => $ldap,
-                ldap_entry => $ldap_entry
-            );
-
-            $self->debug and warn sprintf( "%6d %s\n", $count, $nlc );
-
-            $coderef->($nlc);
-        }
-
-        # handle next search page
-        my ($resp) = $ldap_search->control(LDAP_CONTROL_PAGED) or last PAGE;
-        $cookie = $resp->cookie;
-        if ( !$cookie ) {
-            last PAGE;
-        }
-        $page->cookie($cookie);
-
-    }
-
-    # be nice to the server and stop the search if we still have a cookie
-    if ($cookie) {
-        $page->cookie($cookie);
-        $page->size(0);
-        $ldap->ldap->search(@args);
-        croak "LDAP seach ended prematurely.";
-    }
-
-    return $count;
-
-}
-
 1;
 
 __END__
