@@ -9,7 +9,7 @@ use Net::LDAP::Class::MethodMaker (
 
 );
 
-our $VERSION = '0.18_03';
+our $VERSION = '0.01';
 
 =head1 NAME
 
@@ -59,29 +59,11 @@ sub users {
     if (@_) {
         croak "users() is an accessor (getter) only";
     }
-    my @users = ( @{ $self->primary_users }, @{ $self->secondary_users } );
+    my @users = ( @{ $self->primary_users || [] },
+        @{ $self->secondary_users || [] } );
     return wantarray ? @users : \@users;
 }
 
-=head2 has_user( I<user> )
-
-Returns true if I<user> is amongst users(), false otherwise.
-
-=cut
-
-sub has_user {
-    my $self = shift;
-    my $user = shift or croak "User required";
-    for my $u ( $self->users ) {
-
-        #warn "member $u  <>  user $user";
-        if ( "$u" eq "$user" ) {
-            return 1;
-        }
-    }
-    return 0;
-}
-
 =head2 init_user_class
 
 Override this method in your subclass to set the default User class
@@ -91,23 +73,6 @@ for your Group class.
 
 sub init_user_class { croak "must override init_user_class" }
 
-=head2 name
-
-Same as calling cn() with no arguments. 
-A Group object stringifies to this method.
-
-=cut
-
-sub name { shift->cn }
-
-=head2 stringify
-
-Aliased to name().
-
-=cut
-
-sub stringify { shift->name }
-
 1;
 
 __END__
