@@ -4,7 +4,7 @@ use warnings;
 use Carp;
 use base qw( Net::LDAP::Class::Group );
 
-our $VERSION = '0.18_03';
+our $VERSION = '0.01';
 
 my $RESERVED_GID = 999999;    # used when renaming groups
 
@@ -20,7 +20,7 @@ Net::LDAP::Class::Group::POSIX - group class for POSIX LDAP schema
  package MyLDAPGroup;
  use base qw( Net::LDAP::Class::Group::POSIX );
  
- __PACKAGE__->metadata->setup(
+ __PACKAGE__->meta->setup(
      base_dn             => 'dc=mycompany,dc=com',
     attributes          => __PACKAGE__->POSIX_attributes,
     unique_attributes   => __PACKAGE__->POSIX_unique_attributes,
@@ -300,7 +300,7 @@ sub action_for_update {
                             base   => "ou=People," . $user->base_dn,
                             scope  => "sub",
                             filter => "(uid=$uid)",
-                            attrs  => $user->attributes,
+                            attrs  => [],
                         ],
                         replace => { gidNumber => $new_gid }
                     },
@@ -314,7 +314,7 @@ sub action_for_update {
                             base   => "ou=People," . $self->base_dn,
                             scope  => "sub",
                             filter => "(uid=$uid)",
-                            attrs  => $self->attributes,
+                            attrs  => [],
                         ],
                     }
                 ],
@@ -326,9 +326,8 @@ sub action_for_update {
         push(
             @actions,
             $self->action_for_delete(
-                gidNumber  => $RESERVED_GID,
-                cn         => $old_name,
-                skip_check => 1,
+                gidNumber => $RESERVED_GID,
+                cn        => $old_name
             )
         );
 
@@ -339,7 +338,7 @@ sub action_for_update {
 
 =head2 action_for_delete( [cn => I<cn_value>] )
 
-Returns array ref of actions for removing the organizational unit
+Removes array ref of actions for removing the organizational unit
 and the posixGroup.
 
 You may call this as a class method with an explicit B<cn> key/value
@@ -363,23 +362,15 @@ sub action_for_delete {
         croak "no such Group to delete: $name";
     }
 
-    unless ( $opts{skip_check} ) {
-
-        # set since users() will require it
-        $group->cn($name);
-
-        # clear first so we re-read from the db
-        $group->clear_primary_users;
-        $group->clear_secondary_users;
-
-        if ( scalar @{ $group->users } ) {
-            croak
-                "cannot delete Group $group -- it still has members: [primary] "
-                . join( ", ", map {"$_"} @{ $group->primary_users } )
-                . " [secondary] "
-                . join( ", ", map {"$_"} @{ $group->secondary_users } );
-        }
+    # clear first so we re-read from the db
+    $group->clear_primary_users;
+    $group->clear_secondary_users;
 
+    if ( scalar @{ $group->users } ) {
+        croak "cannot delete Group $group -- it still has members: [primary] "
+            . join( ", ", map {"$_"} @{ $group->primary_users || [] } )
+            . " [secondary] "
+            . join( ", ", map {"$_"} @{ $group->secondary_users || [] } );
     }
 
     my @actions = (
@@ -387,14 +378,14 @@ sub action_for_delete {
                 base   => 'ou=People,' . $group->base_dn,
                 scope  => 'sub',
                 filter => "(ou=$name)",
-                attrs  => $group->attributes,
+                attrs  => [],
             ],
         },
         {   search => [
                 base   => "ou=Group," . $group->base_dn,
                 scope  => "sub",
                 filter => "(cn=$name)",
-                attrs  => $group->attributes,
+                attrs  => [],
             ],
         },
 
@@ -416,13 +407,12 @@ sub fetch_primary_users {
     my $self       = shift;
     my $user_class = $self->user_class or croak "user_class() required";
     my $name       = $self->cn;
-    my @u          = $user_class->find(
+    return $user_class->find(
         base_dn => "ou=$name,ou=People," . $self->base_dn,
         scope   => "sub",
         filter  => "(objectClass=posixAccount)",
         ldap    => $self->ldap,
     );
-    return wantarray ? @u : \@u;
 }
 
 =head2 fetch_secondary_users
@@ -448,17 +438,26 @@ sub fetch_secondary_users {
     return wantarray ? @users : \@users;
 }
 
-=head2 gid
+=head2 name
 
-Alias for gidNumber() attribute.
+Same as calling cn() with no arguments. 
+A Group object stringifies to this method.
 
 =cut
 
-sub gid {
+sub name {
     my $self = shift;
-    $self->gidNumber(@_);
+    return $self->cn;
 }
 
+=head2 stringify
+
+Aliased to name().
+
+=cut
+
+*stringify = \&name;
+
 1;
 
 __END__
