@@ -7,7 +7,7 @@ use base qw( Rose::Object );
 use Net::LDAP::Class::MethodMaker (
     scalar => [qw( base_dn ldap object_classes )], );
 
-our $VERSION = '0.18_03';
+our $VERSION = '0.01';
 
 =head1 NAME
 
@@ -19,7 +19,7 @@ Net::LDAP::Class::Loader - interrogate an LDAP schema
  use strict;
  use base qw( Net::LDAP::Class );
  
- __PACKAGE__->metadata->setup(
+ __PACKAGE__->meta->setup(
     use_loader      => 1,
     ldap            => $ldap,
     object_classes  => [qw( posixAccount )],    # optional
@@ -99,14 +99,13 @@ sub interrogate {
             if ( !@unique ) {
                 my $filter = "(&($name=*) (objectClass=$oc))";
                 my $res    = $self->ldap->search(
-                    base      => $self->base_dn,
-                    scope     => 'sub',
-                    filter    => $filter,
-                    sizelimit => 1,
+                    base   => $self->base_dn,
+                    scope  => 'sub',
+                    filter => $filter,
                 );
 
                 if ( !$res->count ) {
-                    #warn "no match for $filter";
+                    warn "no match for $filter";
                     next MUST;
                 }
 
@@ -133,20 +132,6 @@ sub interrogate {
 
 }
 
-=head2 base_dn
-
-Get/set the base DN used by interrogate().
-
-=head2 ldap
-
-Get/set the Net::LDAP object.
-
-=head2 object_classes
-
-Get/set the array ref of object classes to be used by interrogate().
-
-=cut
-
 1;
 
 __END__
