@@ -3,10 +3,10 @@ use strict;
 use warnings;
 use Carp;
 use base qw( Rose::Object );
-use Clone ();
+use Scalar::Util::Clone;
 use Net::LDAP::Class::Loader;
 
-our $VERSION = '0.18_03';
+our $VERSION = '0.01';
 
 #
 # much of this stolen verbatim from RDBO::Metadata
@@ -42,7 +42,7 @@ Net::LDAP::Class::Metadata - LDAP class metadata
  use strict;
  use base qw( Net::LDAP::Class );
  
- __PACKAGE__->metadata->setup(
+ __PACKAGE__->meta->setup(
     base_dn             => 'dc=mycompany,dc=local',
     attributes          => [qw( name phone email )],
     unique_attributes   => [qw( email )],
@@ -154,19 +154,19 @@ sub setup {
 
 =head2 clone
 
-Returns a clone of the Metadata object. Uses Clone::clone().
+Returns a clone of the Metadata object. Uses Scalar::Util::Clone.
 
 =cut
 
 sub clone {
     my $self = shift;
-    return Clone::clone($self);
+    return Scalar::Util::Clone::clone($self);
 }
 
 =head2 for_class( I<class_name> )
 
 Returns a Metadata object for I<class_name>. Used primarily
-by the metadata() method in Net::LDAP::Class.
+by the meta() method in Net::LDAP::Class.
 
 =cut
 
@@ -202,35 +202,6 @@ sub __get_parents {
     return $class, @parents;
 }
 
-=head2 attributes
-
-Get/set the array ref of attributes for the class.
-
-=head2 base_dn
-
-Get/set the base DN for the class.
-
-=head2 error
-
-Get/set the current error message.
-
-=head2 ldap
-
-Get/set the internal Net::LDAP object.
-
-=head2 object_classes
-
-Get/set the object_classes to be used by the Loader. Ignored if
-you are not using Net::LDAP::Class::Loader.
-
-=head2 unique_attributes
-
-Get/set the array ref of unique attributes for the class.
-These are attributes which may be used to uniquely identify
-a LDAP entry.
-
-=cut
-
 1;
 
 __END__
