@@ -5,7 +5,7 @@ use base qw( Rose::Object::MakeMethods::Generic );
 use Carp;
 use Data::Dump;
 
-our $VERSION = '0.18_03';
+our $VERSION = '0.01';
 
 =head1 NAME
 
@@ -20,7 +20,7 @@ Net::LDAP::Class::MethodMaker - create methods for Net::LDAP::Class classes
     'related_objects'       => [qw( bars )],
  );
  
- __PACKAGE__->metadata->setup(
+ __PACKAGE__->meta->setup(
     base_dn             => 'dc=local',
     attributes          => [qw( foo )],
     unique_attributes   => [qw( foo )],
@@ -90,13 +90,7 @@ sub related_objects {
     elsif ( $interface eq 'get_set' ) {
         my $fetcher_method = $args->{'fetch_method'} || "fetch_$name";
         $methods{$name} = sub {
-            if ( @_ > 1 ) {
-                if ( !$_[0]->validate( $key, $_[1] ) ) {
-                    croak "validate failed for attribute $key: "
-                        . $_[0]->error;
-                }
-                return $_[0]->{$key} = $_[1];
-            }
+            return $_[0]->{$key} = $_[1] if ( @_ > 1 );
             return exists $_[0]->{$key}
                 ? $_[0]->{$key}
                 : $_[0]->$fetcher_method;
@@ -159,21 +153,16 @@ sub ldap_entry {
 
             }
 
-# otherwise, delegate to the ldap_entry
-#unless ( grep { $_ eq $attribute } @{ $self->attributes } ) {
-#                croak
-#                    qq[no such attribute or method "$attribute" defined for package "]
-#                    . ref($self)
-#                    . qq[ -- do you need to add '$attribute' to your setup() call?"];
-#            }
+            # otherwise, delegate to the ldap_entry
+            unless ( grep { $_ eq $attribute } @{ $self->attributes } ) {
+                croak
+                    qq[no such attribute or method "$attribute" defined for package "]
+                    . ref($self)
+                    . qq[ -- do you need to add '$attribute' to your setup() call?"];
+            }
 
             if ( scalar @args ) {
 
-                if ( !$self->validate( $attribute, $args[0] ) ) {
-                    croak "validate failed for attribute $attribute: "
-                        . $self->error;
-                }
-
                 #warn "AUTOLOAD set $attribute -> $args[0]";
                 my @old = $self->ldap_entry->get_value($attribute);
                 $self->ldap_entry->replace( $attribute, $args[0] );
@@ -204,43 +193,6 @@ sub ldap_entry {
     return \%methods;
 }
 
-=head2 object_or_class_meta
-
-Similar to the 'scalar --get-set-init' method type but may be called as a class method,
-in which case it will call through to the class metadata() object.
-
-=cut
-
-sub object_or_class_meta {
-    my ( $class, $name, $args ) = @_;
-
-    my %methods;
-    my $key         = $args->{'hash_key'}    || $name;
-    my $init_method = $args->{'init_method'} || "init_$name";
-
-    $methods{$name} = sub {
-        if ( ref( $_[0] ) ) {
-            return $_[0]->{$key} = $_[1] if ( @_ > 1 );
-
-            if ( $_[0]->can($init_method) ) {
-                return defined $_[0]->{$key}
-                    ? $_[0]->{$key}
-                    : ( $_[0]->{$key} = $_[0]->$init_method() );
-            }
-            else {
-                return defined $_[0]->{$key}
-                    ? $_[0]->{$key}
-                    : ( $_[0]->{$key} = $_[0]->metadata->$key );
-            }
-        }
-        else {
-            return $_[0]->metadata->$key;
-        }
-    };
-
-    return \%methods;
-}
-
 1;
 
 __END__
