@@ -8,7 +8,7 @@ use Net::LDAP::Class::MethodMaker (
     'related_objects'       => [qw( group groups )],
 );
 
-our $VERSION = '0.18_03';
+our $VERSION = '0.01';
 
 =head1 NAME
 
@@ -63,7 +63,7 @@ sub add_to_group {
     if ( !$group->ldap_entry ) {
         croak "Group should be read() prior to adding User $self as a member";
     }
-    my @groups = @{ $self->groups };
+    my @groups = @{ $self->groups || [] };
     my $uniq_method;
     for my $g (@groups) {
         $uniq_method ||= $g->unique_attributes->[0];
@@ -94,7 +94,7 @@ sub remove_from_group {
         croak
             "Group should be read() prior to removing User $self as a member";
     }
-    my @groups = @{ $self->groups };
+    my @groups = @{ $self->groups || [] };
     my @new;
     my $uniq_method;
     for my $g (@groups) {
@@ -121,70 +121,6 @@ Default is to croak indicating you must override this method in your subclass.
 
 sub init_group_class { croak "must override init_group_class" }
 
-=head2 stringify
-
-Aliased to username().
-
-=cut
-
-sub stringify { shift->username }
-
-=head2 username
-
-Get/set the value of the first unique attribute.
-
-=cut
-
-sub username {
-    my $self = shift;
-    my $attr = $self->unique_attributes->[0];
-    return $self->$attr(@_);
-}
-
-=head2 random_string([I<len>])
-
-Returns a random alphanumeric string of length I<len> (default: 10).
-
-=cut
-
-# possible characters (omits common mistaken letters Oh and el)
-my @charset = (
-    'a' .. 'k', 'm' .. 'z', 'A' .. 'N', 'P' .. 'Z', '2' .. '9', '.',
-    ',',        '$',        '?',        '@',        '!'
-);
-
-sub random_string {
-    my $self = shift;
-    my $len = shift || 10;
-
-    # set random seed
-    my ( $usert, $system, $cuser, $csystem ) = times;
-    srand( ( $$ ^ $usert ^ $system ^ time ) );
-
-    # select characters
-    # retry until we get at least:
-    #  * one UPPER
-    #  * one lower
-    #  * one \d
-    #  * one \W
-
-    my @chars;
-    my $str = '';
-    until (    $str =~ /\d/
-            && $str =~ /[A-Z]/
-            && $str =~ /[a-z]/
-            && $str =~ /\W/ )
-    {
-        @chars = ();
-        for ( my $i = 0; $i <= ( $len - 1 ); $i++ ) {
-            $chars[$i] = $charset[ int( rand($#charset) + 1 ) ];
-        }
-        $str = join( '', @chars );
-    }
-
-    return $str;
-}
-
 1;
 
 __END__
