@@ -6,10 +6,10 @@ use Data::Dump qw( dump );
 use Digest::SHA1;
 use MIME::Base64;
 use base qw( Net::LDAP::Class::User );
-use Net::LDAP::Class::MethodMaker ( 'scalar --get_set_init' =>
+use Rose::Object::MakeMethods::Generic ( 'scalar --get_set_init' =>
         [qw( default_shell default_home_dir default_email_suffix )], );
 
-our $VERSION = '0.18_03';
+our $VERSION = '0.01';
 
 # see http://www.ietf.org/rfc/rfc2307.txt
 
@@ -23,7 +23,7 @@ Net::LDAP::Class::User::POSIX - user class for POSIX LDAP schema
  package MyLDAPUser;
  use base qw( Net::LDAP::Class::User::POSIX );
  
- __PACKAGE__->metadata->setup(
+ __PACKAGE__->meta->setup(
     base_dn             => 'dc=mycompany,dc=com',
     attributes          => __PACKAGE__->POSIX_attributes,
     unique_attributes   => __PACKAGE__->POSIX_unique_attributes,
@@ -114,6 +114,30 @@ You likely want to override this in your subclass.
 
 sub init_group_class {'Net::LDAP::Class::Group::POSIX'}
 
+=head2 username
+
+Same as calling uid() with no arguments, just easier to remember. 
+Objects will stringify using this method.
+
+Example:
+
+  print $user;  # same as print $user->username;
+ 
+=cut
+
+sub username {
+    my $self = shift;
+    return $self->uid;
+}
+
+=head2 stringify
+
+Aliased to username().
+
+=cut
+
+*stringify = \&username;
+
 =head2 action_for_create([ uid => I<username>, uidNumber => I<nnn> ])
 
 Returns hash ref suitable for creating a Net::LDAP::Batch::Action::Add.
@@ -134,43 +158,28 @@ sub action_for_create {
     my ( $group, $gid, $givenName, $sn, $gecos, $email, $hash )
         = $self->setup_for_write;
 
-    # default attributes
     # note that not setting a homeDirectory or sn is a schema error
-    my %attr = (
-        objectClass  => [ "top", "person", "posixAccount" ],
-        cn           => $username,
-        givenName    => $givenName,
-        sn           => $sn,
-        uid          => $username,
-        userPassword => "$hash",
-        uidNumber    => $uid,
-        gidNumber    => $gid,
-        gecos        => $gecos,
-        homeDirectory    => $self->default_home_dir . "/$username",
-        loginShell       => $self->default_shell,
-        shadowMin        => "-1",
-        shadowMax        => "99999",
-        shadowWarning    => "7",
-        shadowLastChange => "13767",
-        mail             => $email
-    );
-
-    # mix in whatever has been set
-    for my $name ( keys %{ $self->{_not_yet_set} } ) {
-
-        #warn "set $name => $self->{_not_yet_set}->{$name}";
-        unless ( exists $attr{$name} ) {
-            $attr{$name} = delete $self->{_not_yet_set}->{$name};
-        }
-        else {
-            $attr{$name} = $self->{_not_yet_set}->{$name};
-        }
-    }
-
     my @actions = (
         add => {
             dn   => "uid=$username,ou=$group,ou=People," . $self->base_dn,
-            attr => [%attr],
+            attr => [
+                objectClass  => [ "top", "person", "posixAccount" ],
+                cn           => $username,
+                givenName    => $givenName,
+                sn           => $sn,
+                uid          => $username,
+                userPassword => "$hash",
+                uidNumber    => $uid,
+                gidNumber    => $gid,
+                gecos        => $gecos,
+                homeDirectory    => $self->default_home_dir . "/$username",
+                loginShell       => $self->default_shell,
+                shadowMin        => "-1",
+                shadowMax        => "99999",
+                shadowWarning    => "7",
+                shadowLastChange => "13767",
+                mail             => $email
+            ],
         }
     );
 
@@ -191,7 +200,7 @@ sub action_for_create {
                     base   => "ou=Group,$group_dn",
                     scope  => "sub",
                     filter => "(cn=$group_name)",
-                    attrs  => $group->attributes,
+                    attrs  => [],
                 ],
                 replace => { memberUid => [@newUids] }
             };
@@ -230,13 +239,6 @@ sub setup_for_write {
         gidNumber => $self->gidNumber,
         ldap      => $self->ldap
         )->read;
-
-    if ( !defined $group ) {
-        croak "group "
-            . $self->gidNumber
-            . " is not yet in LDAP. Must add it before creating User";
-    }
-
     if ( ref $group and $group->isa('Net::LDAP::Class::Group::POSIX') ) {
         $gid   = $group->gidNumber;
         $group = $group->cn;
@@ -250,16 +252,11 @@ sub setup_for_write {
 
     # the name logic breaks horribly here for anything but trivial cases.
     my @name_parts = split( m/\s+/, $self->gecos || '' );
-    my $givenName = $self->givenName;
-    $givenName = shift(@name_parts) unless defined $givenName;
-    my $sn = $self->sn;
-    $sn = join( ' ', @name_parts ) unless defined $sn;
-    my $gecos = $self->gecos;
-    $gecos = join( ' ', $givenName, $sn ) unless defined $gecos;
+    my $givenName = $self->givenName || shift(@name_parts);
+    my $sn        = $self->sn        || join( ' ', @name_parts );
+    my $gecos     = $self->gecos     || join( ' ', $givenName, $sn );
 
-    my $email = $self->mail;
-    $email = ( $self->username . $self->default_email_suffix )
-        unless defined $email;
+    my $email = $self->mail || $self->username . $self->default_email_suffix;
 
     # set password if not set.
     # this is useful for default random passwords.
@@ -334,7 +331,7 @@ sub action_for_update {
                     base   => "ou=People," . $self->base_dn,
                     scope  => "sub",
                     filter => "(uid=$username)",
-                    attrs  => $self->attributes,
+                    attrs  => [],
                 ],
                 replace => \%replace
             }
@@ -359,7 +356,7 @@ sub action_for_update {
                         base   => "ou=People," . $self->base_dn,
                         scope  => "sub",
                         filter => "(uid=$username)",
-                        attrs  => $self->attributes,
+                        attrs  => [],
                     ],
                     replace => { gidNumber => $self->group->gidNumber },
                 },
@@ -373,7 +370,7 @@ sub action_for_update {
                         base   => "ou=People," . $self->base_dn,
                         scope  => "sub",
                         filter => "(uid=$username)",
-                        attrs  => $self->attributes,
+                        attrs  => [],
                     ],
                 }
             ],
@@ -391,9 +388,6 @@ sub action_for_update {
 
         my $existing_groups = $self->fetch_groups;
         my %existing = map { $_->gidNumber => $_ } @$existing_groups;
-
-        # the delete $self->{groups} has helpful side effect of clearing
-        # cache.
         my %new = map { $_->gidNumber => $_ } @{ delete $self->{groups} };
 
         # which should be added
@@ -408,7 +402,7 @@ sub action_for_update {
                         base   => "ou=Group,$group_dn",
                         scope  => "one",
                         filter => "(cn=$group_name)",
-                        attrs  => $new{$gid}->attributes,
+                        attrs  => [],
                     ],
                     replace => { memberUid => [@newUids] }
                 };
@@ -429,7 +423,7 @@ sub action_for_update {
                         base   => "ou=Group,$group_dn",
                         scope  => "one",
                         filter => "(cn=$group_name)",
-                        attrs  => $existing{$gid}->attributes,
+                        attrs  => [],
                     ],
                     replace => { memberUid => [@newUids] }
                 };
@@ -478,7 +472,7 @@ sub action_for_delete {
                 base   => "ou=People," . $self->base_dn,
                 scope  => "sub",
                 filter => "(uid=$username)",
-                attrs  => $self->attributes,
+                attrs  => [],
             ]
         }
     );
@@ -519,31 +513,18 @@ group_class().
 =cut
 
 sub fetch_groups {
-    my $self  = shift;
+    my $self = shift;
     my $class = $self->group_class or croak "group_class() required";
-    my @g     = $class->find(
+    return $class->find(
         ldap    => $self->ldap,
         base_dn => 'ou=Group,' . $self->group->base_dn,
         filter  => "(memberUid=" . $self->uid . ")",
     );
-    return wantarray ? @g : \@g;
 }
 
-=head2 gid
-
-Alias for gidNumber() attribute.
-
-=cut
-
-sub gid {
-    my $self = shift;
-    $self->gidNumber(@_);
-}
-
-=head2 password([I<plain_password>])
-
-Convenience wrapper around userPassword() attribute method.
+=head2 userPassword([I<plain_password>])
 
+Special case of overriding attribute name with its own method.
 This method will SHA-1-hashify I<plain_password> using ssha_hash()
 and set the hash
 in the ldap_entry(). If no argument is supplied, returns the hash
@@ -551,7 +532,7 @@ string set in ldap_entry() (if any).
 
 =cut
 
-sub password {
+sub userPassword {
     my $self      = shift;
     my $attribute = 'userPassword';
 
@@ -599,6 +580,41 @@ sub new_password {
     return $self->ssha_hash( $self->random_string(@_) );
 }
 
+=head2 random_string([I<len>])
+
+Returns a random alphanumeric string of length I<len> (default: 8).
+
+=cut
+
+# possible characters (omits common mistaken letters Oh and el)
+my @charset = (
+    'a' .. 'k', 'm' .. 'z', 'A' .. 'N', 'P' .. 'Z', '1' .. '9', '.',
+    ':',        '^',        '?',        '@',        '('
+);
+
+sub random_string {
+    my $self = shift;
+    my $len = shift || 8;
+
+    # set random seed
+    my ( $usert, $system, $cuser, $csystem ) = times;
+    srand( ( $$ ^ $usert ^ $system ^ time ) );
+
+    # select characters
+    # retry until we get at least one non-alpha char
+    my @chars;
+    do {
+        @chars = ();
+        for ( my $i = 0; $i <= ( $len - 1 ); $i++ ) {
+            $chars[$i] = $charset[ int( rand($#charset) + 1 ) ];
+        }
+    } until ( grep /[123456789\.:\^\?@\(]/, @chars );
+
+    # pack characters into scalar
+    my $tmp_passwd = pack( 'a' x $len, @chars );
+    return $tmp_passwd;
+}
+
 sub _random_seed {
     my ($len) = @_;
     my ( @charset, $usert, $system, $cuser,      $csystem );
